@@ -22,6 +22,7 @@
 #    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 import os
+from collections import OrderedDict
 from typing import Dict, Any, List
 
 import yaml
@@ -45,6 +46,9 @@ class JointboxYamlTools:
         yaml.add_representer(TimePeriod, cls.__represent_to_str_class)
         yaml.add_constructor("tag:yaml.org,2002:map", cls.__construct_mapping)
         yaml.add_constructor("!include", cls.__construct_include)
+        # Dumper
+        yaml.add_representer(OrderedDict, cls.__represent_mapping)
+        yaml.add_multi_representer(dict, lambda dumper, value: dumper.represent_mapping("tag:yaml.org,2002:map", value))
 
     @classmethod
     def __represent_dict_subclass(cls, dumper, data: dict):
@@ -61,6 +65,30 @@ class JointboxYamlTools:
         node = dumper.represent_str(str(data))
         return node
 
+    @classmethod
+    def __represent_mapping(cls, dumper: yaml.Dumper, mapping):
+        value: Any = []
+        node = yaml.MappingNode("tag:yaml.org,2002:map", value, flow_style=None)
+        if dumper.alias_key is not None:
+            dumper.represented_objects[dumper.alias_key] = node
+        best_style = True
+        if hasattr(mapping, "items"):
+            mapping = list(mapping.items())
+        for item_key, item_value in mapping:
+            node_key = dumper.represent_data(item_key)
+            node_value = dumper.represent_data(item_value)
+            if not (isinstance(node_key, yaml.ScalarNode) and not node_key.style):
+                best_style = False
+            if not (isinstance(node_value, yaml.ScalarNode) and not node_value.style):
+                best_style = False
+            value.append((node_key, node_value))
+
+        if dumper.default_flow_style is not None:
+            node.flow_style = dumper.default_flow_style
+        else:
+            node.flow_style = best_style
+        return node
+
     @classmethod
     def __construct_include(cls, loader: yaml.Loader, node: yaml.Node):
         include_file_name = node.value
@@ -151,7 +179,9 @@ class JointboxYamlTools:
                             "Expected a mapping for merging, but found {}".format(type(item)),
                             value_node.start_mark,
                         )
-                    merge_pairs.extend(item.items())
+                    # merge_pairs.extend(item.items())
+                # Corvis: do we really need to merge the content of the list?
+                return value
             else:
                 raise yaml.constructor.ConstructorError(
                     "While constructing a mapping",
@@ -182,7 +212,7 @@ class JointboxYamlTools:
                 # Add key node to seen keys, for sequence merge values.
                 seen_keys[key] = None
 
-        return dict(pairs)
+        return OrderedDict(pairs)
 
     @classmethod
     def __load_yaml_internal(cls, file_path: str):
